==> 1.0.7.tar.gz: lib/src/utils/x_size.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

/// 距离
class D {
  static double? sp(double? fontSize) {
    if (fontSize == null) {
      return null;
    }
    return fontSize.sp;
  }

  static double? h(double? height) {
    if (height == null || height == double.infinity) {
      return height;
    }
    return height.r;
  }

  static double? w(double? width) {
    if (width == null || width == double.infinity) {
      return width;
    }
    return width.r;
  }
}

/// Padding
class P {
  static EdgeInsets all(double width) {
    return EdgeInsets.all(width.r);
  }

  static EdgeInsets hv({double? horizontal, double? vertical}) {
    return EdgeInsets.symmetric(
      horizontal: horizontal == null ? 0.0 : horizontal.r,
      vertical: vertical == null ? 0.0 : vertical.r,
    );
  }

  static EdgeInsets only(
      {double? left, double? top, double? right, double? bottom}) {
    return EdgeInsets.only(
      left: left == null ? 0.0 : left.r,
      right: right == null ? 0.0 : right.r,
      top: top == null ? 0.0 : top.r,
      bottom: bottom == null ? 0.0 : bottom.r,
    );
  }
}

/// 间隔
class G {
  /// 水平间隔
  static Widget h(double width) {
    return SizedBox(width: width.r);
  }

  /// 垂直间隔
  static Widget v(double height) {
    return SizedBox(height: height.r);
  }

  static const Widget empty = SizedBox();
}

/// 边界半径
class XRadius {
  static BorderRadius? all(double? radius) {
    if (radius == null) return null;
    return BorderRadius.circular(D.w(radius)!);
  }

  static BorderRadius? top(double? radius) {
    if (radius == null) return null;
    return BorderRadius.vertical(top: Radius.circular(radius.r));
  }

  static BorderRadius? bottom(double? radius) {
    if (radius == null) return null;
    return BorderRadius.vertical(bottom: Radius.circular(radius.r));
  }

  static BorderRadius? left(double? radius) {
    if (radius == null) return null;
    return BorderRadius.horizontal(left: Radius.circular(radius.r));
  }

  static BorderRadius? right(double? radius) {
    if (radius == null) return null;
    return BorderRadius.horizontal(right: Radius.circular(radius.r));
  }

  static BorderRadius only({
    double? topLeft,
    double? topRight,
    double? bottomLeft,
    double? bottomRight,
  }) {
    return BorderRadius.only(
      topLeft: topLeft == null ? Radius.zero : Radius.circular(topLeft.r),
      topRight: topRight == null ? Radius.zero : Radius.circular(topRight.r),
      bottomLeft:
          bottomLeft == null ? Radius.zero : Radius.circular(bottomLeft.r),
      bottomRight:
          bottomRight == null ? Radius.zero : Radius.circular(bottomRight.r),
    );
  }
}

==> 1.0.8.tar.gz: lib/src/utils/x_size.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

/// 距离
class D {
  static sp(double? fontSize) {
    if (fontSize == null) {
      return null;
    }
    return fontSize.sp;
  }

  static h(double? height) {
    if (height == null || height == double.infinity) {
      return height;
    }
    return height.r;
  }

  static w(double? width) {
    if (width == null || width == double.infinity) {
      return width;
    }
    return width.r;
  }
}

/// Padding
class P {
  static EdgeInsets all(double width) {
    return EdgeInsets.all(width.r);
  }

  static EdgeInsets hv({double? horizontal, double? vertical}) {
    return EdgeInsets.symmetric(
      horizontal: horizontal == null ? 0.0 : horizontal.r,
      vertical: vertical == null ? 0.0 : vertical.r,
    );
  }

  static EdgeInsets only(
      {double? left, double? top, double? right, double? bottom}) {
    return EdgeInsets.only(
      left: left == null ? 0.0 : left.r,
      right: right == null ? 0.0 : right.r,
      top: top == null ? 0.0 : top.r,
      bottom: bottom == null ? 0.0 : bottom.r,
    );
  }
}

/// 间隔
class G {
  /// 水平间隔
  static Widget h(double width) {
    return SizedBox(width: width.r);
  }

  /// 垂直间隔
  static Widget v(double height) {
    return SizedBox(height: height.r);
  }

  static const Widget empty = SizedBox();
}

/// 边界半径
class XRadius {
  static all(double? radius) {
    if (radius == null) return null;
    return BorderRadius.circular(D.w(radius)!);
  }

  static top(double? radius) {
    if (radius == null) return null;
    return BorderRadius.vertical(top: Radius.circular(radius.r));
  }

  static bottom(double? radius) {
    if (radius == null) return null;
    return BorderRadius.vertical(bottom: Radius.circular(radius.r));
  }

  static left(double? radius) {
    if (radius == null) return null;
    return BorderRadius.horizontal(left: Radius.circular(radius.r));
  }

  static right(double? radius) {
    if (radius == null) return null;
    return BorderRadius.horizontal(right: Radius.circular(radius.r));
  }

  static BorderRadius only({
    double? topLeft,
    double? topRight,
    double? bottomLeft,
    double? bottomRight,
  }) {
    return BorderRadius.only(
      topLeft: topLeft == null ? Radius.zero : Radius.circular(topLeft.r),
      topRight: topRight == null ? Radius.zero : Radius.circular(topRight.r),
      bottomLeft:
          bottomLeft == null ? Radius.zero : Radius.circular(bottomLeft.r),
      bottomRight:
          bottomRight == null ? Radius.zero : Radius.circular(bottomRight.r),
    );
  }
}
